R/pds-maps.R
convert_taxa_names.Rd
Assign each taxon code to a broad species group
convert_taxa_names(data)
A dataframe with taxa codes under a column named "catch_taxon"
data with a fish_group column
data
fish_group