Reads the vessel_type label preprocess_landings() resolves from the
Airtable frame. Both codes the live forms use resolve, so alert 12 is
currently never raised.
Arguments
- submissions
Output of
validation_submissions().
Reads the vessel_type label preprocess_landings() resolves from the
Airtable frame. Both codes the live forms use resolve, so alert 12 is
currently never raised.
Output of validation_submissions().