Reshape one raw landings table into the flat long catch table
Source:R/preprocessing-surveys.R
reshape_landings.RdThe whole of preprocessing for a single form version, as a pure function so it can be exercised without cloud storage.
Arguments
- raw
A raw landings table as written by
ingest_landings().- version
Form version,
"v2"or"v3".- labels
Output of
survey_labels().