Reads the trips parquet written by coasts::ingest_pds_trips() and the
per-trip descriptors written by describe_pds_tracks(), merges trips that
are really one, and flags anomalous duration, distance and signal quality.
Usage
validate_pds_trips(log_threshold = logger::DEBUG)Arguments
- log_threshold
The (standard Apache logj4) log level used as a threshold for the logging infrastructure. See logger::log_levels for more details