This function takes the submission-level view of the landings and validates the temporal info associated to each survey.
Arguments
- submissions
Output of
validation_submissions().- hrs
Limit of trip duration in hours to be considered a valid catch session.
- submission_delay
Limit for maximum difference (in days) between the survey submission date and the recorded landing date.
Examples
if (FALSE) { # \dontrun{
conf <- read_config()
landings <- get_weighted_landings(conf)
validate_surveys_time(validation_submissions(landings), hrs = 18, 28)
} # }